==> hubzero-cms-2.1.0_2.1.14.10-1+deb8.tar.gz: source/cms/core/components/com_search/admin/views/solr/tmpl/overview.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2015 HUBzero Foundation, LLC.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
 * @license   http://opensource.org/licenses/MIT MIT
 */

// No direct access.
defined('_HZEXEC_') or die();

Toolbar::title(Lang::txt('Solr Search: Overview'));
Toolbar::preferences($this->option, '550');
$this->css('solr');
$option = $this->option;

Submenu::addEntry(
	Lang::txt('Overview'),
	'index.php?option='.$option.'&task=configure',
	true
);
Submenu::addEntry(
	Lang::txt('Search Index'),
	'index.php?option='.$option.'&task=searchindex'
);
Submenu::addEntry(
	Lang::txt('Index Blacklist'),
	'index.php?option='.$option.'&task=manageBlacklist'
);
?>
<div id="widget-container" class="com_search">
	<div class="widget">
		<div class="inner">
			<div class="title"><div>Solr Status</div></div>
			<div class="sub-title"><div class="sub-title-inner">Last Document Insert: <?php echo $this->lastInsert; ?></div></div>
			<div class="sub-title"><div class="sub-title-inner">Mechanism: <?php echo ucfirst($this->mechanism); ?></div> </div>
			<div class="content">
				<div class="content-inner">
					<div class="status">
						<?php if ($this->status === true) : ?>
							<div class="status-message">
								<div class="good"></div>
								<p>The search engine is responding.</p>
								<p class="emph">Last insert was <?php echo $this->lastInsert; ?></p>
							</div> <!-- /.status-message -->
						<?php else : ?>
							<div class="alert"></div>
							<div class="status-message">
								<p><?php echo Lang::txt('COM_SEARCH_NOT_RESPONDING'); ?></p>
								<p><?php echo Lang::txt('COM_SEARCH_CHECK_CONFIG'); ?></p>
							</div> <!-- /.status-message -->
						<?php endif; ?>
					</div> <!-- /.status -->
				</div><!-- /.content-inner -->
			</div><!-- /.content -->
		</div><!-- /.inner -->
	</div>

	<!-- @TODO: Make view -->
	<?php if (isset($this->queueStats) && false): ?>
		<div class="widget">
			<div class="inner">
				<div class="title">
					<div><?php echo Lang::txt('COM_SEARCH_QUEUE_STATUS'); ?></div>
				</div>
				<div class="sub-title">
					<div class="sub-title-inner">
						<?php echo Lang::txt('COM_SEARCH_QUEUE_LAST_SERVICE') . ':' . Date::of($this->queueStats['modified'])->relative(); ?>
					</div>
				</div>
				<div class="sub-title">
					<div class="sub-title-inner">
						<?php echo Lang::txt('COM_SEARCH_QUEUE_AVERAGE_SERVICE') . ':' . $this->queueStats['serviceTime'] . 'minutes'; ?>
					</div>
				</div>
				<div class="content">
					<div class="content-inner">
						<div class="status"></div> <!-- /.status -->
					</div><!-- /.content-inner -->
				</div><!-- /.content -->
			</div><!-- /.inner -->
		</div>
	<?php endif; ?>
</div>

==> hubzero-cms-2.2.0_2.2.6.0-1+deb8.tar.gz: source/cms/core/components/com_search/admin/views/solr/tmpl/overview.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2015 HUBzero Foundation, LLC.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
 * @license   http://opensource.org/licenses/MIT MIT
 */

// No direct access.
defined('_HZEXEC_') or die();

Toolbar::title(Lang::txt('Solr Search: Overview'));
Toolbar::preferences($this->option, '550');
$this->css('solr');
$option = $this->option;

Submenu::addEntry(
	Lang::txt('Overview'),
	'index.php?option='.$option.'&task=configure',
	true
);
Submenu::addEntry(
	Lang::txt('Search Index'),
	'index.php?option='.$option.'&task=searchindex'
);
Submenu::addEntry(
	Lang::txt('Searchable Components'),
	'index.php?option='.$option.'&task=display&controller=searchable'
);
Submenu::addEntry(
	Lang::txt('Index Blacklist'),
	'index.php?option='.$option.'&task=manageBlacklist'
);
?>
<div id="widget-container" class="com_search">
	<div class="widget">
		<div class="inner">
			<div class="title"><div>Solr Status</div></div>
			<div class="sub-title"><div class="sub-title-inner">Last Document Insert: <?php echo $this->lastInsert; ?></div></div>
			<div class="sub-title"><div class="sub-title-inner">Mechanism: <?php echo ucfirst($this->mechanism); ?></div> </div>
			<div class="content">
				<div class="content-inner">
					<div class="status">
						<?php if ($this->status === true) : ?>
							<div class="status-message">
								<div class="good"></div>
								<p>The search engine is responding.</p>
								<p class="emph">Last insert was <?php echo $this->lastInsert; ?></p>
							</div> <!-- /.status-message -->
						<?php else : ?>
							<div class="alert"></div>
							<div class="status-message">
								<p><?php echo Lang::txt('COM_SEARCH_NOT_RESPONDING'); ?></p>
								<p><?php echo Lang::txt('COM_SEARCH_CHECK_CONFIG'); ?></p>
							</div> <!-- /.status-message -->
						<?php endif; ?>
					</div> <!-- /.status -->
				</div><!-- /.content-inner -->
			</div><!-- /.content -->
		</div><!-- /.inner -->
	</div>

	<!-- @TODO: Make view -->
	<?php if (isset($this->queueStats) && false): ?>
		<div class="widget">
			<div class="inner">
				<div class="title">
					<div><?php echo Lang::txt('COM_SEARCH_QUEUE_STATUS'); ?></div>
				</div>
				<div class="sub-title">
					<div class="sub-title-inner">
						<?php echo Lang::txt('COM_SEARCH_QUEUE_LAST_SERVICE') . ':' . Date::of($this->queueStats['modified'])->relative(); ?>
					</div>
				</div>
				<div class="sub-title">
					<div class="sub-title-inner">
						<?php echo Lang::txt('COM_SEARCH_QUEUE_AVERAGE_SERVICE') . ':' . $this->queueStats['serviceTime'] . 'minutes'; ?>
					</div>
				</div>
				<div class="content">
					<div class="content-inner">
						<div class="status"></div> <!-- /.status -->
					</div><!-- /.content-inner -->
				</div><!-- /.content -->
			</div><!-- /.inner -->
		</div>
	<?php endif; ?>
</div>
